Dictalchemy
===========

Dictalchemy adds asdict() and fromdict() methods to SQLAlchemy declarative models.

Documentation
-------------

Documentation can be found at `http://pythonhosted.org/dictalchemy/ <http://pythonhosted.org/dictalchemy/>`_

Source
------

The source is hosted at `http://github.com/danielholmstrom/dictalchemy <http://github.com/danielholmstrom/dictalchemy>`_.

Licence
-------

Dictalchemy is MIT licenced.
